<?xml version="1.0" ?><!DOCTYPE TS><TS language="th_TH" version="2.0">
<context>
    <name>QuickLaunchButton</name>
    <message>
        <source>Move left</source>
        <translation>ย้ายไปทางซ้าย</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation>ย้ายไปทางขวา</translation>
    </message>
    <message>
        <source>Remove from quicklaunch</source>
        <translation>ลบออกจากตัวเรียกโปรแกรมด่วน</translation>
    </message>
</context>
<context>
    <name>RazorQuickLaunch</name>
    <message>
        <source>Drop Error</source>
        <translation>การหย่อนขัดข้อง</translation>
    </message>
    <message>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>แฟ้ม/URL &apos;%1&apos; ไม่สามารถฝังตัวไปยังตัวเรียกใช้งานด่วนได้ในตอนนี้</translation>
    </message>
</context>
</TS>